@@ -8,6 +8,10 @@ num=`ps -ef | grep ${cnfpath} | grep -v grep | grep -v vim | wc -l`
         exit 0
 }
 
-./cluster_mgr ${cnfpath} >../log/std.log 2>&1
-
+ulimit -c unlimited
+if test "$USE_VALGRIND" = ""; then
+	./cluster_mgr ${cnfpath} >../log/std.log 2>&1
+else
+	valgrind --leak-check=full --trace-children=yes --undef-value-errors=no ./cluster_mgr ${cnfpath} >../log/std.log 2>&1
+fi
 ps -ef | grep ${cnfpath} | grep -v grep
